package com.alipay.api.domain;

import java.util.Date;
import java.util.List;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;
import com.alipay.api.internal.mapping.ApiListField;

/**
 * 线下店铺Leads模型
 *
 * @author auto create
 * @since 1.0, 2016-03-24 00:35:58
 */
public class LeadsQueryResponse extends AlipayObject {

	private static final long serialVersionUID = 1697593472212713282L;

	/**
	 * 联系地址
	 */
	@ApiField("address")
	private String address;

	/**
	 * 分店名
	 */
	@ApiField("branch_shop_name")
	private String branchShopName;

	/**
	 * 品牌名，不填写则默认为“其它品牌”
	 */
	@ApiField("brand_name")
	private String brandName;

	/**
	 * 最细的类目编号
	 */
	@ApiField("category_id")
	private String categoryId;

	/**
	 * 城市编码。
国标码，详见国家统计局数据。
	 */
	@ApiField("city_code")
	private String cityCode;

	/**
	 * leads认领时间
	 */
	@ApiField("claim_time")
	private Date claimTime;

	/**
	 * 公司名称
	 */
	@ApiField("company_name")
	private String companyName;

	/**
	 * 联系人名称
	 */
	@ApiField("contact_name")
	private String contactName;

	/**
	 * 联系人手机号
	 */
	@ApiField("contact_number")
	private String contactNumber;

	/**
	 * leads创建时间
	 */
	@ApiField("create_time")
	private Date createTime;

	/**
	 * 门店内景图。
建议上传3-10张，尺寸在2000px＊1500px以上，格式为bmp、png、jpg、gif，不超过10M。
	 */
	@ApiListField("detail_images")
	@ApiField("string")
	private List<String> detailImages;

	/**
	 * 门店内景图名称列表
	 */
	@ApiListField("detail_images_name")
	@ApiField("string")
	private List<String> detailImagesName;

	/**
	 * 门店内景图URL列表
	 */
	@ApiListField("detail_images_url")
	@ApiField("string")
	private List<String> detailImagesUrl;

	/**
	 * 区县编码。
国标码，详见国家统计局数据。
	 */
	@ApiField("district_code")
	private String districtCode;

	/**
	 * 扩展属性，JSON格式：keyMerchant-是否重点商户（T/F）
	 */
	@ApiField("ext_info")
	private String extInfo;

	/**
	 * 是否隐藏：T-是，F-否。
	 */
	@ApiField("is_hidden")
	private String isHidden;

	/**
	 * 是否系统导入leads：T-是，F-否。
	 */
	@ApiField("is_system_import")
	private String isSystemImport;

	/**
	 * 纬度，注：高德坐标系，需要服务商引导用户校准经纬度
	 */
	@ApiField("latitude")
	private Long latitude;

	/**
	 * 支付宝leads ID，后续的增删改查接口都使用该ID作为主键
	 */
	@ApiField("leads_id")
	private String leadsId;

	/**
	 * PUBLIC：公海 PRIVATE：私海
	 */
	@ApiField("leads_range")
	private String leadsRange;

	/**
	 * 经度，注：高德坐标系，需要服务商引导用户校准经纬度
	 */
	@ApiField("longitude")
	private Long longitude;

	/**
	 * 门店首图。
建议尺寸在2000px＊1500px以上，格式为bmp、png、jpg、gif，不超过10M。
	 */
	@ApiField("main_image")
	private String mainImage;

	/**
	 * 门店首图名称
	 */
	@ApiField("main_image_name")
	private String mainImageName;

	/**
	 * 门店首图URL
	 */
	@ApiField("main_image_url")
	private String mainImageUrl;

	/**
	 * 主门店名
	 */
	@ApiField("main_shop_name")
	private String mainShopName;

	/**
	 * 备注
	 */
	@ApiField("memo")
	private String memo;

	/**
	 * 操作用户的支付账号id
	 */
	@ApiField("op_id")
	private String opId;

	/**
	 * 其他联系方式
	 */
	@ApiField("other_contact_info")
	private String otherContactInfo;

	/**
	 * 省份编码。
国标码，详见国家统计局数据。
	 */
	@ApiField("province_code")
	private String provinceCode;

	/**
	 * 请求ID，标识本次创建请求
	 */
	@ApiField("request_id")
	private String requestId;

	/**
	 * leads状态。
INIT：未认领，CLAIMED：已认领，CONFIRMING：待商户确认，RELATED：已关联商户，OPENING：开店中，OPENED：已开店。
	 */
	@ApiField("status")
	private String status;

	public String getAddress() {
		return this.address;
	}
	public void setAddress(String address) {
		this.address = address;
	}

	public String getBranchShopName() {
		return this.branchShopName;
	}
	public void setBranchShopName(String branchShopName) {
		this.branchShopName = branchShopName;
	}

	public String getBrandName() {
		return this.brandName;
	}
	public void setBrandName(String brandName) {
		this.brandName = brandName;
	}

	public String getCategoryId() {
		return this.categoryId;
	}
	public void setCategoryId(String categoryId) {
		this.categoryId = categoryId;
	}

	public String getCityCode() {
		return this.cityCode;
	}
	public void setCityCode(String cityCode) {
		this.cityCode = cityCode;
	}

	public Date getClaimTime() {
		return this.claimTime;
	}
	public void setClaimTime(Date claimTime) {
		this.claimTime = claimTime;
	}

	public String getCompanyName() {
		return this.companyName;
	}
	public void setCompanyName(String companyName) {
		this.companyName = companyName;
	}

	public String getContactName() {
		return this.contactName;
	}
	public void setContactName(String contactName) {
		this.contactName = contactName;
	}

	public String getContactNumber() {
		return this.contactNumber;
	}
	public void setContactNumber(String contactNumber) {
		this.contactNumber = contactNumber;
	}

	public Date getCreateTime() {
		return this.createTime;
	}
	public void setCreateTime(Date createTime) {
		this.createTime = createTime;
	}

	public List<String> getDetailImages() {
		return this.detailImages;
	}
	public void setDetailImages(List<String> detailImages) {
		this.detailImages = detailImages;
	}

	public List<String> getDetailImagesName() {
		return this.detailImagesName;
	}
	public void setDetailImagesName(List<String> detailImagesName) {
		this.detailImagesName = detailImagesName;
	}

	public List<String> getDetailImagesUrl() {
		return this.detailImagesUrl;
	}
	public void setDetailImagesUrl(List<String> detailImagesUrl) {
		this.detailImagesUrl = detailImagesUrl;
	}

	public String getDistrictCode() {
		return this.districtCode;
	}
	public void setDistrictCode(String districtCode) {
		this.districtCode = districtCode;
	}

	public String getExtInfo() {
		return this.extInfo;
	}
	public void setExtInfo(String extInfo) {
		this.extInfo = extInfo;
	}

	public String getIsHidden() {
		return this.isHidden;
	}
	public void setIsHidden(String isHidden) {
		this.isHidden = isHidden;
	}

	public String getIsSystemImport() {
		return this.isSystemImport;
	}
	public void setIsSystemImport(String isSystemImport) {
		this.isSystemImport = isSystemImport;
	}

	public Long getLatitude() {
		return this.latitude;
	}
	public void setLatitude(Long latitude) {
		this.latitude = latitude;
	}

	public String getLeadsId() {
		return this.leadsId;
	}
	public void setLeadsId(String leadsId) {
		this.leadsId = leadsId;
	}

	public String getLeadsRange() {
		return this.leadsRange;
	}
	public void setLeadsRange(String leadsRange) {
		this.leadsRange = leadsRange;
	}

	public Long getLongitude() {
		return this.longitude;
	}
	public void setLongitude(Long longitude) {
		this.longitude = longitude;
	}

	public String getMainImage() {
		return this.mainImage;
	}
	public void setMainImage(String mainImage) {
		this.mainImage = mainImage;
	}

	public String getMainImageName() {
		return this.mainImageName;
	}
	public void setMainImageName(String mainImageName) {
		this.mainImageName = mainImageName;
	}

	public String getMainImageUrl() {
		return this.mainImageUrl;
	}
	public void setMainImageUrl(String mainImageUrl) {
		this.mainImageUrl = mainImageUrl;
	}

	public String getMainShopName() {
		return this.mainShopName;
	}
	public void setMainShopName(String mainShopName) {
		this.mainShopName = mainShopName;
	}

	public String getMemo() {
		return this.memo;
	}
	public void setMemo(String memo) {
		this.memo = memo;
	}

	public String getOpId() {
		return this.opId;
	}
	public void setOpId(String opId) {
		this.opId = opId;
	}

	public String getOtherContactInfo() {
		return this.otherContactInfo;
	}
	public void setOtherContactInfo(String otherContactInfo) {
		this.otherContactInfo = otherContactInfo;
	}

	public String getProvinceCode() {
		return this.provinceCode;
	}
	public void setProvinceCode(String provinceCode) {
		this.provinceCode = provinceCode;
	}

	public String getRequestId() {
		return this.requestId;
	}
	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	public String getStatus() {
		return this.status;
	}
	public void setStatus(String status) {
		this.status = status;
	}

}
